File$$Methods extension

on

Properties

absoluteFile File?

Available on File, provided by the File$$Methods extension

from: public java.io.File getAbsoluteFile() The returned object must be released after use, by calling the release method.
no setter
absolutePath → JString?

Available on File, provided by the File$$Methods extension

from: public java.lang.String getAbsolutePath() The returned object must be released after use, by calling the release method.
no setter
canonicalFile File?

Available on File, provided by the File$$Methods extension

from: public java.io.File getCanonicalFile() The returned object must be released after use, by calling the release method.
no setter
canonicalPath → JString?

Available on File, provided by the File$$Methods extension

from: public java.lang.String getCanonicalPath() The returned object must be released after use, by calling the release method.
no setter
freeSpace int

Available on File, provided by the File$$Methods extension

from: public long getFreeSpace()
no setter
isAbsolute bool

Available on File, provided by the File$$Methods extension

from: public boolean isAbsolute()
no setter
isDirectory bool

Available on File, provided by the File$$Methods extension

from: public boolean isDirectory()
no setter
isFile bool

Available on File, provided by the File$$Methods extension

from: public boolean isFile()
no setter
isHidden bool

Available on File, provided by the File$$Methods extension

from: public boolean isHidden()
no setter
name → JString?

Available on File, provided by the File$$Methods extension

from: public java.lang.String getName() The returned object must be released after use, by calling the release method.
no setter
parent → JString?

Available on File, provided by the File$$Methods extension

from: public java.lang.String getParent() The returned object must be released after use, by calling the release method.
no setter
parentFile File?

Available on File, provided by the File$$Methods extension

from: public java.io.File getParentFile() The returned object must be released after use, by calling the release method.
no setter
path → JString?

Available on File, provided by the File$$Methods extension

from: public java.lang.String getPath() The returned object must be released after use, by calling the release method.
no setter
totalSpace int

Available on File, provided by the File$$Methods extension

from: public long getTotalSpace()
no setter
usableSpace int

Available on File, provided by the File$$Methods extension

from: public long getUsableSpace()
no setter

Methods

canExecute() bool

Available on File, provided by the File$$Methods extension

from: public boolean canExecute()
canRead() bool

Available on File, provided by the File$$Methods extension

from: public boolean canRead()
canWrite() bool

Available on File, provided by the File$$Methods extension

from: public boolean canWrite()
compareTo(File? file) int

Available on File, provided by the File$$Methods extension

from: public int compareTo(java.io.File file)
createNewFile() bool

Available on File, provided by the File$$Methods extension

from: public boolean createNewFile()
delete() bool

Available on File, provided by the File$$Methods extension

from: public boolean delete()
deleteOnExit() → void

Available on File, provided by the File$$Methods extension

from: public void deleteOnExit()
equals(JObject? object) bool

Available on File, provided by the File$$Methods extension

from: public boolean equals(java.lang.Object object)
exists() bool

Available on File, provided by the File$$Methods extension

from: public boolean exists()
hashCode$1() int

Available on File, provided by the File$$Methods extension

from: public int hashCode()
lastModified() int

Available on File, provided by the File$$Methods extension

from: public long lastModified()
length() int

Available on File, provided by the File$$Methods extension

from: public long length()
list() → JArray<JString?>?

Available on File, provided by the File$$Methods extension

from: public java.lang.String[] list() The returned object must be released after use, by calling the release method.
list$1(JObject? filenameFilter) → JArray<JString?>?

Available on File, provided by the File$$Methods extension

from: public java.lang.String[] list(java.io.FilenameFilter filenameFilter) The returned object must be released after use, by calling the release method.
listFiles() → JArray<File?>?

Available on File, provided by the File$$Methods extension

from: public java.io.File[] listFiles() The returned object must be released after use, by calling the release method.
listFiles$1(JObject? fileFilter) → JArray<File?>?

Available on File, provided by the File$$Methods extension

from: public java.io.File[] listFiles(java.io.FileFilter fileFilter) The returned object must be released after use, by calling the release method.
listFiles$2(JObject? filenameFilter) → JArray<File?>?

Available on File, provided by the File$$Methods extension

from: public java.io.File[] listFiles(java.io.FilenameFilter filenameFilter) The returned object must be released after use, by calling the release method.
mkdir() bool

Available on File, provided by the File$$Methods extension

from: public boolean mkdir()
mkdirs() bool

Available on File, provided by the File$$Methods extension

from: public boolean mkdirs()
renameTo(File? file) bool

Available on File, provided by the File$$Methods extension

from: public boolean renameTo(java.io.File file)
setExecutable(bool z) bool

Available on File, provided by the File$$Methods extension

from: public boolean setExecutable(boolean z)
setExecutable$1(bool z, bool z1) bool

Available on File, provided by the File$$Methods extension

from: public boolean setExecutable(boolean z, boolean z1)
setLastModified(int j) bool

Available on File, provided by the File$$Methods extension

from: public boolean setLastModified(long j)
setReadable(bool z) bool

Available on File, provided by the File$$Methods extension

from: public boolean setReadable(boolean z)
setReadable$1(bool z, bool z1) bool

Available on File, provided by the File$$Methods extension

from: public boolean setReadable(boolean z, boolean z1)
setReadOnly() bool

Available on File, provided by the File$$Methods extension

from: public boolean setReadOnly()
setWritable(bool z) bool

Available on File, provided by the File$$Methods extension

from: public boolean setWritable(boolean z)
setWritable$1(bool z, bool z1) bool

Available on File, provided by the File$$Methods extension

from: public boolean setWritable(boolean z, boolean z1)
toPath() → JObject?

Available on File, provided by the File$$Methods extension

from: public java.nio.file.Path toPath() The returned object must be released after use, by calling the release method.
toString$1() → JString?

Available on File, provided by the File$$Methods extension

from: public java.lang.String toString() The returned object must be released after use, by calling the release method.
toURI() → JObject?

Available on File, provided by the File$$Methods extension

from: public java.net.URI toURI() The returned object must be released after use, by calling the release method.
toURL() → JObject?

Available on File, provided by the File$$Methods extension

from: public java.net.URL toURL() The returned object must be released after use, by calling the release method.

Operators

operator <(File? file) bool

Available on File, provided by the File$$Methods extension

operator <=(File? file) bool

Available on File, provided by the File$$Methods extension

operator >(File? file) bool

Available on File, provided by the File$$Methods extension

operator >=(File? file) bool

Available on File, provided by the File$$Methods extension