NSFileManager extension type

NSFileManager

on
  • ObjCObject
Available extensions

Constructors

NSFileManager.as(ObjCObject other)
Constructs a NSFileManager that points to the same underlying object as other.
NSFileManager.fromPointer(Pointer<ObjCObjectImpl> other, {bool retain = false, bool release = false})
Constructs a NSFileManager that wraps the given raw object pointer.

Properties

hashCode int
The hash code for this object.
no setterinherited
homeDirectoryForCurrentUser → NSURL

Available on NSFileManager, provided by the NSUserInformation extension

homeDirectoryForCurrentUser
no setter
object$ → ObjCObject
final
ref → ObjCObjectRef
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporaryDirectory → NSURL

Available on NSFileManager, provided by the NSUserInformation extension

temporaryDirectory
no setter

Methods

createDirectoryAtURL(NSURL url, {required bool withIntermediateDirectories, NSDictionary? attributes}) bool

Available on NSFileManager, provided by the NSFileManager$Methods extension

createDirectoryAtURL:withIntermediateDirectories:attributes:error:
homeDirectoryForUser(NSString userName) → NSURL?

Available on NSFileManager, provided by the NSUserInformation extension

homeDirectoryForUser:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
URLForDirectory(NSSearchPathDirectory directory, {required int inDomain, NSURL? appropriateForURL, required bool create}) → NSURL?

Available on NSFileManager, provided by the NSFileManager$Methods extension

URLForDirectory:inDomain:appropriateForURL:create:error:

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getDefaultManager() NSFileManager
defaultManager
isA(ObjCObject obj) bool
Returns whether obj is an instance of NSFileManager.