path_manager library

Classes

AndroidPathManager
The Android implementation of PlatformPathManager using JNI via FFI.
FoundationPathManager
The iOS/macOS implementation of PlatformPathManager using Apple Foundation APIs via FFI.
PathManager
A class providing unified access to commonly used directories on the host file system.
PlatformPathManager
The platform-specific interface contract for resolving directory paths.

Exceptions / Errors

BackupExclusionConflictException
Exception thrown by PathManager.getApplicationNoBackupDirectory when the designated no-backup directory (__no_backup__) already exists on the filesystem, but has not been marked with the backup exclusion flag.
MissingPlatformDirectoryException
Exception thrown by PathManager when a requested platform directory cannot be resolved or is not supported on the host platform.