PlatformPathManager class abstract

The platform-specific interface contract for resolving directory paths.

Implementations of this class register themselves via the static instance field at runtime. Typically, this is done automatically by Flutter's generated plugin registrant for the target platform.

Implementers

Constructors

PlatformPathManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getApplicationNoBackupDirectory() Future<String?>
Gets the absolute path to a default directory that is excluded from platform backup systems.
getApplicationSupportPath() Future<String?>
Gets the absolute path to the application support directory on the host filesystem.
getCachesPath() Future<String?>
Gets the absolute path to the application caches directory on the host filesystem.
getDocumentsPath() Future<String?>
Gets the absolute path to the user documents directory on the host filesystem.
getTemporaryPath() Future<String?>
Gets the absolute path to the temporary directory on the host filesystem.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApplicationPathIsExcludedFromBackup(String path, bool exclude) Future<void>
Sets whether the filesystem entity at path should be excluded from backups.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PlatformPathManager
The active platform-specific implementation of PlatformPathManager.
getter/setter pair