Context$$Methods extension
- on
Properties
- applicationContext → Context?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Context getApplicationContext()The returned object must be released after use, by calling thereleasemethod.no setter - applicationInfo → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.pm.ApplicationInfo getApplicationInfo()The returned object must be released after use, by calling thereleasemethod.no setter - assets → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.res.AssetManager getAssets()The returned object must be released after use, by calling thereleasemethod.no setter - attributionSource → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public android.content.AttributionSource getAttributionSource()The returned object must be released after use, by calling thereleasemethod.no setter - attributionTag → JString?
-
Available on Context, provided by the Context$$Methods extension
from:public java.lang.String getAttributionTag()The returned object must be released after use, by calling thereleasemethod.no setter - cacheDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getCacheDir()The returned object must be released after use, by calling thereleasemethod.no setter - classLoader → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.ClassLoader getClassLoader()The returned object must be released after use, by calling thereleasemethod.no setter - codeCacheDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getCodeCacheDir()The returned object must be released after use, by calling thereleasemethod.no setter - contentResolver → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.ContentResolver getContentResolver()The returned object must be released after use, by calling thereleasemethod.no setter - dataDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getDataDir()The returned object must be released after use, by calling thereleasemethod.no setter - deviceId → int
-
Available on Context, provided by the Context$$Methods extension
from:public int getDeviceId()no setter - display → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public android.view.Display getDisplay()The returned object must be released after use, by calling thereleasemethod.no setter - externalCacheDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getExternalCacheDir()The returned object must be released after use, by calling thereleasemethod.no setter -
externalCacheDirs
→ JArray<
File?> ? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File[] getExternalCacheDirs()The returned object must be released after use, by calling thereleasemethod.no setter -
externalMediaDirs
→ JArray<
File?> ? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File[] getExternalMediaDirs()The returned object must be released after use, by calling thereleasemethod.no setter - filesDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getFilesDir()The returned object must be released after use, by calling thereleasemethod.no setter - isDeviceProtectedStorage → bool
-
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean isDeviceProtectedStorage()no setter - isRestricted → bool
-
Available on Context, provided by the Context$$Methods extension
from:public boolean isRestricted()no setter - isUiContext → bool
-
Available on Context, provided by the Context$$Methods extension
from:public boolean isUiContext()no setter - mainExecutor → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public java.util.concurrent.Executor getMainExecutor()The returned object must be released after use, by calling thereleasemethod.no setter - mainLooper → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.os.Looper getMainLooper()The returned object must be released after use, by calling thereleasemethod.no setter - noBackupFilesDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getNoBackupFilesDir()The returned object must be released after use, by calling thereleasemethod.no setter - obbDir → File?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getObbDir()The returned object must be released after use, by calling thereleasemethod.no setter -
obbDirs
→ JArray<
File?> ? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File[] getObbDirs()The returned object must be released after use, by calling thereleasemethod.no setter - opPackageName → JString?
-
Available on Context, provided by the Context$$Methods extension
from:public java.lang.String getOpPackageName()The returned object must be released after use, by calling thereleasemethod.no setter - packageCodePath → JString?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.String getPackageCodePath()The returned object must be released after use, by calling thereleasemethod.no setter - packageManager → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.pm.PackageManager getPackageManager()The returned object must be released after use, by calling thereleasemethod.no setter - packageName → JString?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.String getPackageName()The returned object must be released after use, by calling thereleasemethod.no setter - packageResourcePath → JString?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.String getPackageResourcePath()The returned object must be released after use, by calling thereleasemethod.no setter - params → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public android.content.ContextParams getParams()The returned object must be released after use, by calling thereleasemethod.no setter - resources → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.res.Resources getResources()The returned object must be released after use, by calling thereleasemethod.no setter - theme → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.res.Resources$Theme getTheme()The returned object must be released after use, by calling thereleasemethod.no setter - theme$1 ← int
-
Available on Context, provided by the Context$$Methods extension
from:public abstract void setTheme(int i)no getter - wallpaper → JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract android.graphics.drawable.Drawable getWallpaper()The returned object must be released after use, by calling thereleasemethod.no setter - wallpaper$1 ← JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract void setWallpaper(android.graphics.Bitmap bitmap)no getter - wallpaper$2 ← JObject?
-
Available on Context, provided by the Context$$Methods extension
from:public abstract void setWallpaper(java.io.InputStream inputStream)no getter - wallpaperDesiredMinimumHeight → int
-
Available on Context, provided by the Context$$Methods extension
from:public abstract int getWallpaperDesiredMinimumHeight()no setter - wallpaperDesiredMinimumWidth → int
-
Available on Context, provided by the Context$$Methods extension
from:public abstract int getWallpaperDesiredMinimumWidth()no setter
Methods
-
bindIsolatedService(
JObject? intent, Context$BindServiceFlags? bindServiceFlags, JString? string, JObject? executor, JObject? serviceConnection) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindIsolatedService(android.content.Intent intent, android.content.Context$BindServiceFlags bindServiceFlags, java.lang.String string, java.util.concurrent.Executor executor, android.content.ServiceConnection serviceConnection) -
bindIsolatedService$1(
JObject? intent, int i, JString? string, JObject? executor, JObject? serviceConnection) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindIsolatedService(android.content.Intent intent, int i, java.lang.String string, java.util.concurrent.Executor executor, android.content.ServiceConnection serviceConnection) -
bindService(
JObject? intent, Context$BindServiceFlags? bindServiceFlags, JObject? executor, JObject? serviceConnection) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindService(android.content.Intent intent, android.content.Context$BindServiceFlags bindServiceFlags, java.util.concurrent.Executor executor, android.content.ServiceConnection serviceConnection) -
bindService$1(
JObject? intent, JObject? serviceConnection, Context$BindServiceFlags? bindServiceFlags) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindService(android.content.Intent intent, android.content.ServiceConnection serviceConnection, android.content.Context$BindServiceFlags bindServiceFlags) -
bindService$2(
JObject? intent, JObject? serviceConnection, int i) → bool -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean bindService(android.content.Intent intent, android.content.ServiceConnection serviceConnection, int i) -
bindService$3(
JObject? intent, int i, JObject? executor, JObject? serviceConnection) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindService(android.content.Intent intent, int i, java.util.concurrent.Executor executor, android.content.ServiceConnection serviceConnection) -
bindServiceAsUser(
JObject? intent, JObject? serviceConnection, Context$BindServiceFlags? bindServiceFlags, JObject? userHandle) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindServiceAsUser(android.content.Intent intent, android.content.ServiceConnection serviceConnection, android.content.Context$BindServiceFlags bindServiceFlags, android.os.UserHandle userHandle) -
bindServiceAsUser$1(
JObject? intent, JObject? serviceConnection, int i, JObject? userHandle) → bool -
Available on Context, provided by the Context$$Methods extension
from:public boolean bindServiceAsUser(android.content.Intent intent, android.content.ServiceConnection serviceConnection, int i, android.os.UserHandle userHandle) -
checkCallingOrSelfPermission(
JString? string) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkCallingOrSelfPermission(java.lang.String string) -
checkCallingOrSelfUriPermission(
JObject? uri, int i) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkCallingOrSelfUriPermission(android.net.Uri uri, int i) -
checkCallingOrSelfUriPermissions(
JList< JObject?> ? list, int i) → JIntArray? -
Available on Context, provided by the Context$$Methods extension
from:public int[] checkCallingOrSelfUriPermissions(java.util.List<android.net.Uri> list, int i)The returned object must be released after use, by calling thereleasemethod. -
checkCallingPermission(
JString? string) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkCallingPermission(java.lang.String string) -
checkCallingUriPermission(
JObject? uri, int i) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkCallingUriPermission(android.net.Uri uri, int i) -
checkCallingUriPermissions(
JList< JObject?> ? list, int i) → JIntArray? -
Available on Context, provided by the Context$$Methods extension
from:public int[] checkCallingUriPermissions(java.util.List<android.net.Uri> list, int i)The returned object must be released after use, by calling thereleasemethod. -
checkContentUriPermissionFull(
JObject? uri, int i, int i1, int i2) → int -
Available on Context, provided by the Context$$Methods extension
from:public int checkContentUriPermissionFull(android.net.Uri uri, int i, int i1, int i2) -
checkPermission(
JString? string, int i, int i1) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkPermission(java.lang.String string, int i, int i1) -
checkSelfPermission(
JString? string) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkSelfPermission(java.lang.String string) -
checkUriPermission(
JObject? uri, int i, int i1, int i2) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkUriPermission(android.net.Uri uri, int i, int i1, int i2) -
checkUriPermission$1(
JObject? uri, JString? string, JString? string1, int i, int i1, int i2) → int -
Available on Context, provided by the Context$$Methods extension
from:public abstract int checkUriPermission(android.net.Uri uri, java.lang.String string, java.lang.String string1, int i, int i1, int i2) -
checkUriPermissions(
JList< JObject?> ? list, int i, int i1, int i2) → JIntArray? -
Available on Context, provided by the Context$$Methods extension
from:public int[] checkUriPermissions(java.util.List<android.net.Uri> list, int i, int i1, int i2)The returned object must be released after use, by calling thereleasemethod. -
clearWallpaper(
) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void clearWallpaper() -
createAttributionContext(
JString? string) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public android.content.Context createAttributionContext(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
createConfigurationContext(
JObject? configuration) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Context createConfigurationContext(android.content.res.Configuration configuration)The returned object must be released after use, by calling thereleasemethod. -
createContext(
JObject? contextParams) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public android.content.Context createContext(android.content.ContextParams contextParams)The returned object must be released after use, by calling thereleasemethod. -
createContextForSplit(
JString? string) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Context createContextForSplit(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
createDeviceContext(
int i) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public android.content.Context createDeviceContext(int i)The returned object must be released after use, by calling thereleasemethod. -
createDeviceProtectedStorageContext(
) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Context createDeviceProtectedStorageContext()The returned object must be released after use, by calling thereleasemethod. -
createDisplayContext(
JObject? display) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Context createDisplayContext(android.view.Display display)The returned object must be released after use, by calling thereleasemethod. -
createPackageContext(
JString? string, int i) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Context createPackageContext(java.lang.String string, int i)The returned object must be released after use, by calling thereleasemethod. -
createWindowContext(
JObject? display, int i, JObject? bundle) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public android.content.Context createWindowContext(android.view.Display display, int i, android.os.Bundle bundle)The returned object must be released after use, by calling thereleasemethod. -
createWindowContext$1(
int i, JObject? bundle) → Context? -
Available on Context, provided by the Context$$Methods extension
from:public android.content.Context createWindowContext(int i, android.os.Bundle bundle)The returned object must be released after use, by calling thereleasemethod. -
databaseList(
) → JArray< JString?> ? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.String[] databaseList()The returned object must be released after use, by calling thereleasemethod. -
deleteDatabase(
JString? string) → bool -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean deleteDatabase(java.lang.String string) -
deleteFile(
JString? string) → bool -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean deleteFile(java.lang.String string) -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean deleteSharedPreferences(java.lang.String string) -
enforceCallingOrSelfPermission(
JString? string, JString? string1) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforceCallingOrSelfPermission(java.lang.String string, java.lang.String string1) -
enforceCallingOrSelfUriPermission(
JObject? uri, int i, JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforceCallingOrSelfUriPermission(android.net.Uri uri, int i, java.lang.String string) -
enforceCallingPermission(
JString? string, JString? string1) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforceCallingPermission(java.lang.String string, java.lang.String string1) -
enforceCallingUriPermission(
JObject? uri, int i, JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforceCallingUriPermission(android.net.Uri uri, int i, java.lang.String string) -
enforcePermission(
JString? string, int i, int i1, JString? string1) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforcePermission(java.lang.String string, int i, int i1, java.lang.String string1) -
enforceUriPermission(
JObject? uri, int i, int i1, int i2, JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforceUriPermission(android.net.Uri uri, int i, int i1, int i2, java.lang.String string) -
enforceUriPermission$1(
JObject? uri, JString? string, JString? string1, int i, int i1, int i2, JString? string2) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void enforceUriPermission(android.net.Uri uri, java.lang.String string, java.lang.String string1, int i, int i1, int i2, java.lang.String string2) -
fileList(
) → JArray< JString?> ? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.String[] fileList()The returned object must be released after use, by calling thereleasemethod. -
getColor(
int i) → int -
Available on Context, provided by the Context$$Methods extension
from:public final int getColor(int i) -
getColorStateList(
int i) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final android.content.res.ColorStateList getColorStateList(int i)The returned object must be released after use, by calling thereleasemethod. -
getDatabasePath(
JString? string) → File? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getDatabasePath(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
getDir(
JString? string, int i) → File? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getDir(java.lang.String string, int i)The returned object must be released after use, by calling thereleasemethod. -
getDrawable(
int i) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final android.graphics.drawable.Drawable getDrawable(int i)The returned object must be released after use, by calling thereleasemethod. -
getExternalFilesDir(
JString? string) → File? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getExternalFilesDir(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
getExternalFilesDirs(
JString? string) → JArray< File?> ? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File[] getExternalFilesDirs(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
getFileStreamPath(
JString? string) → File? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.File getFileStreamPath(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.SharedPreferences getSharedPreferences(java.lang.String string, int i)The returned object must be released after use, by calling thereleasemethod. -
getString(
int i) → JString? -
Available on Context, provided by the Context$$Methods extension
from:public final java.lang.String getString(int i)The returned object must be released after use, by calling thereleasemethod. -
getString$1(
int i, JArray< JObject?> ? objects) → JString? -
Available on Context, provided by the Context$$Methods extension
from:public final java.lang.String getString(int i, java.lang.Object[] objects)The returned object must be released after use, by calling thereleasemethod. -
getSystemService<
$T extends JObject?> (JObject? class$) → $T? -
Available on Context, provided by the Context$$Methods extension
from:public final T getSystemService(java.lang.Class<T> class)The returned object must be released after use, by calling thereleasemethod. -
getSystemService$1(
JString? string) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.Object getSystemService(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
getSystemServiceName(
JObject? class$) → JString? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.lang.String getSystemServiceName(java.lang.Class<?> class)The returned object must be released after use, by calling thereleasemethod. -
getText(
int i) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final java.lang.CharSequence getText(int i)The returned object must be released after use, by calling thereleasemethod. -
grantUriPermission(
JString? string, JObject? uri, int i) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void grantUriPermission(java.lang.String string, android.net.Uri uri, int i) -
moveDatabaseFrom(
Context? context, JString? string) → bool -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean moveDatabaseFrom(android.content.Context context, java.lang.String string) -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean moveSharedPreferencesFrom(android.content.Context context, java.lang.String string) -
obtainStyledAttributes(
JObject? attributeSet, JIntArray? is$) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final android.content.res.TypedArray obtainStyledAttributes(android.util.AttributeSet attributeSet, int[] is)The returned object must be released after use, by calling thereleasemethod. -
obtainStyledAttributes$1(
JObject? attributeSet, JIntArray? is$, int i, int i1) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final android.content.res.TypedArray obtainStyledAttributes(android.util.AttributeSet attributeSet, int[] is, int i, int i1)The returned object must be released after use, by calling thereleasemethod. -
obtainStyledAttributes$2(
int i, JIntArray? is$) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final android.content.res.TypedArray obtainStyledAttributes(int i, int[] is)The returned object must be released after use, by calling thereleasemethod. -
obtainStyledAttributes$3(
JIntArray? is$) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public final android.content.res.TypedArray obtainStyledAttributes(int[] is)The returned object must be released after use, by calling thereleasemethod. -
openFileInput(
JString? string) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.FileInputStream openFileInput(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
openFileOutput(
JString? string, int i) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract java.io.FileOutputStream openFileOutput(java.lang.String string, int i)The returned object must be released after use, by calling thereleasemethod. -
openOrCreateDatabase(
JString? string, int i, JObject? cursorFactory) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.database.sqlite.SQLiteDatabase openOrCreateDatabase(java.lang.String string, int i, android.database.sqlite.SQLiteDatabase$CursorFactory cursorFactory)The returned object must be released after use, by calling thereleasemethod. -
openOrCreateDatabase$1(
JString? string, int i, JObject? cursorFactory, JObject? databaseErrorHandler) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.database.sqlite.SQLiteDatabase openOrCreateDatabase(java.lang.String string, int i, android.database.sqlite.SQLiteDatabase$CursorFactory cursorFactory, android.database.DatabaseErrorHandler databaseErrorHandler)The returned object must be released after use, by calling thereleasemethod. -
peekWallpaper(
) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.graphics.drawable.Drawable peekWallpaper()The returned object must be released after use, by calling thereleasemethod. -
registerComponentCallbacks(
JObject? componentCallbacks) → void -
Available on Context, provided by the Context$$Methods extension
from:public void registerComponentCallbacks(android.content.ComponentCallbacks componentCallbacks) -
registerDeviceIdChangeListener(
JObject? executor, JObject? intConsumer) → void -
Available on Context, provided by the Context$$Methods extension
from:public void registerDeviceIdChangeListener(java.util.concurrent.Executor executor, java.util.function.IntConsumer intConsumer) -
registerReceiver(
JObject? broadcastReceiver, JObject? intentFilter) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Intent registerReceiver(android.content.BroadcastReceiver broadcastReceiver, android.content.IntentFilter intentFilter)The returned object must be released after use, by calling thereleasemethod. -
registerReceiver$1(
JObject? broadcastReceiver, JObject? intentFilter, int i) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Intent registerReceiver(android.content.BroadcastReceiver broadcastReceiver, android.content.IntentFilter intentFilter, int i)The returned object must be released after use, by calling thereleasemethod. -
registerReceiver$2(
JObject? broadcastReceiver, JObject? intentFilter, JString? string, JObject? handler) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Intent registerReceiver(android.content.BroadcastReceiver broadcastReceiver, android.content.IntentFilter intentFilter, java.lang.String string, android.os.Handler handler)The returned object must be released after use, by calling thereleasemethod. -
registerReceiver$3(
JObject? broadcastReceiver, JObject? intentFilter, JString? string, JObject? handler, int i) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.Intent registerReceiver(android.content.BroadcastReceiver broadcastReceiver, android.content.IntentFilter intentFilter, java.lang.String string, android.os.Handler handler, int i)The returned object must be released after use, by calling thereleasemethod. -
removeStickyBroadcast(
JObject? intent) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void removeStickyBroadcast(android.content.Intent intent) -
removeStickyBroadcastAsUser(
JObject? intent, JObject? userHandle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void removeStickyBroadcastAsUser(android.content.Intent intent, android.os.UserHandle userHandle) -
revokeSelfPermissionOnKill(
JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public void revokeSelfPermissionOnKill(java.lang.String string) -
revokeSelfPermissionsOnKill(
JObject? collection) → void -
Available on Context, provided by the Context$$Methods extension
from:public void revokeSelfPermissionsOnKill(java.util.Collection<java.lang.String> collection) -
revokeUriPermission(
JObject? uri, int i) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void revokeUriPermission(android.net.Uri uri, int i) -
revokeUriPermission$1(
JString? string, JObject? uri, int i) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void revokeUriPermission(java.lang.String string, android.net.Uri uri, int i) -
sendBroadcast(
JObject? intent) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendBroadcast(android.content.Intent intent) -
sendBroadcast$1(
JObject? intent, JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendBroadcast(android.content.Intent intent, java.lang.String string) -
sendBroadcast$2(
JObject? intent, JString? string, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public void sendBroadcast(android.content.Intent intent, java.lang.String string, android.os.Bundle bundle) -
sendBroadcastAsUser(
JObject? intent, JObject? userHandle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendBroadcastAsUser(android.content.Intent intent, android.os.UserHandle userHandle) -
sendBroadcastAsUser$1(
JObject? intent, JObject? userHandle, JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendBroadcastAsUser(android.content.Intent intent, android.os.UserHandle userHandle, java.lang.String string) -
sendBroadcastWithMultiplePermissions(
JObject? intent, JArray< JString?> ? strings) → void -
Available on Context, provided by the Context$$Methods extension
from:public void sendBroadcastWithMultiplePermissions(android.content.Intent intent, java.lang.String[] strings) -
sendOrderedBroadcast(
JObject? intent, JString? string) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendOrderedBroadcast(android.content.Intent intent, java.lang.String string) -
sendOrderedBroadcast$1(
JObject? intent, JString? string, JObject? broadcastReceiver, JObject? handler, int i, JString? string1, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendOrderedBroadcast(android.content.Intent intent, java.lang.String string, android.content.BroadcastReceiver broadcastReceiver, android.os.Handler handler, int i, java.lang.String string1, android.os.Bundle bundle) -
sendOrderedBroadcast$2(
JObject? intent, JString? string, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public void sendOrderedBroadcast(android.content.Intent intent, java.lang.String string, android.os.Bundle bundle) -
sendOrderedBroadcast$3(
JObject? intent, JString? string, JObject? bundle, JObject? broadcastReceiver, JObject? handler, int i, JString? string1, JObject? bundle1) → void -
Available on Context, provided by the Context$$Methods extension
from:public void sendOrderedBroadcast(android.content.Intent intent, java.lang.String string, android.os.Bundle bundle, android.content.BroadcastReceiver broadcastReceiver, android.os.Handler handler, int i, java.lang.String string1, android.os.Bundle bundle1) -
sendOrderedBroadcast$4(
JObject? intent, JString? string, JString? string1, JObject? broadcastReceiver, JObject? handler, int i, JString? string2, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public void sendOrderedBroadcast(android.content.Intent intent, java.lang.String string, java.lang.String string1, android.content.BroadcastReceiver broadcastReceiver, android.os.Handler handler, int i, java.lang.String string2, android.os.Bundle bundle) -
sendOrderedBroadcastAsUser(
JObject? intent, JObject? userHandle, JString? string, JObject? broadcastReceiver, JObject? handler, int i, JString? string1, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendOrderedBroadcastAsUser(android.content.Intent intent, android.os.UserHandle userHandle, java.lang.String string, android.content.BroadcastReceiver broadcastReceiver, android.os.Handler handler, int i, java.lang.String string1, android.os.Bundle bundle) -
sendStickyBroadcast(
JObject? intent) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendStickyBroadcast(android.content.Intent intent) -
sendStickyBroadcast$1(
JObject? intent, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public void sendStickyBroadcast(android.content.Intent intent, android.os.Bundle bundle) -
sendStickyBroadcastAsUser(
JObject? intent, JObject? userHandle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendStickyBroadcastAsUser(android.content.Intent intent, android.os.UserHandle userHandle) -
sendStickyOrderedBroadcast(
JObject? intent, JObject? broadcastReceiver, JObject? handler, int i, JString? string, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendStickyOrderedBroadcast(android.content.Intent intent, android.content.BroadcastReceiver broadcastReceiver, android.os.Handler handler, int i, java.lang.String string, android.os.Bundle bundle) -
sendStickyOrderedBroadcastAsUser(
JObject? intent, JObject? userHandle, JObject? broadcastReceiver, JObject? handler, int i, JString? string, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void sendStickyOrderedBroadcastAsUser(android.content.Intent intent, android.os.UserHandle userHandle, android.content.BroadcastReceiver broadcastReceiver, android.os.Handler handler, int i, java.lang.String string, android.os.Bundle bundle) -
startActivities(
JArray< JObject?> ? intents) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void startActivities(android.content.Intent[] intents) -
startActivities$1(
JArray< JObject?> ? intents, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void startActivities(android.content.Intent[] intents, android.os.Bundle bundle) -
startActivity(
JObject? intent) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void startActivity(android.content.Intent intent) -
startActivity$1(
JObject? intent, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void startActivity(android.content.Intent intent, android.os.Bundle bundle) -
startForegroundService(
JObject? intent) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.ComponentName startForegroundService(android.content.Intent intent)The returned object must be released after use, by calling thereleasemethod. -
startInstrumentation(
JObject? componentName, JString? string, JObject? bundle) → bool -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean startInstrumentation(android.content.ComponentName componentName, java.lang.String string, android.os.Bundle bundle) -
startIntentSender(
JObject? intentSender, JObject? intent, int i, int i1, int i2) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void startIntentSender(android.content.IntentSender intentSender, android.content.Intent intent, int i, int i1, int i2) -
startIntentSender$1(
JObject? intentSender, JObject? intent, int i, int i1, int i2, JObject? bundle) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void startIntentSender(android.content.IntentSender intentSender, android.content.Intent intent, int i, int i1, int i2, android.os.Bundle bundle) -
startService(
JObject? intent) → JObject? -
Available on Context, provided by the Context$$Methods extension
from:public abstract android.content.ComponentName startService(android.content.Intent intent)The returned object must be released after use, by calling thereleasemethod. -
stopService(
JObject? intent) → bool -
Available on Context, provided by the Context$$Methods extension
from:public abstract boolean stopService(android.content.Intent intent) -
unbindService(
JObject? serviceConnection) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void unbindService(android.content.ServiceConnection serviceConnection) -
unregisterComponentCallbacks(
JObject? componentCallbacks) → void -
Available on Context, provided by the Context$$Methods extension
from:public void unregisterComponentCallbacks(android.content.ComponentCallbacks componentCallbacks) -
unregisterDeviceIdChangeListener(
JObject? intConsumer) → void -
Available on Context, provided by the Context$$Methods extension
from:public void unregisterDeviceIdChangeListener(java.util.function.IntConsumer intConsumer) -
unregisterReceiver(
JObject? broadcastReceiver) → void -
Available on Context, provided by the Context$$Methods extension
from:public abstract void unregisterReceiver(android.content.BroadcastReceiver broadcastReceiver) -
updateServiceGroup(
JObject? serviceConnection, int i, int i1) → void -
Available on Context, provided by the Context$$Methods extension
from:public void updateServiceGroup(android.content.ServiceConnection serviceConnection, int i, int i1)