File extension type
from: java.io.File
- on
-
- JObject
- Available extensions
Constructors
- File(File? file, JString? string)
-
from:
public void <init>(java.io.File file, java.lang.String string)The returned object must be released after use, by calling thereleasemethod.factory - File.new$1(JString? string)
-
from:
public void <init>(java.lang.String string)The returned object must be released after use, by calling thereleasemethod.factory - File.new$2(JString? string, JString? string1)
-
from:
public void <init>(java.lang.String string, java.lang.String string1)The returned object must be released after use, by calling thereleasemethod.factory - File.new$3(JObject? uRI)
-
from:
public void <init>(java.net.URI uRI)The returned object must be released after use, by calling thereleasemethod.factory
Properties
- absoluteFile → File?
-
Available on File, provided by the File$$Methods extension
from:public java.io.File getAbsoluteFile()The returned object must be released after use, by calling thereleasemethod.no setter - absolutePath → JString?
-
Available on File, provided by the File$$Methods extension
from:public java.lang.String getAbsolutePath()The returned object must be released after use, by calling thereleasemethod.no setter - canonicalFile → File?
-
Available on File, provided by the File$$Methods extension
from:public java.io.File getCanonicalFile()The returned object must be released after use, by calling thereleasemethod.no setter - canonicalPath → JString?
-
Available on File, provided by the File$$Methods extension
from:public java.lang.String getCanonicalPath()The returned object must be released after use, by calling thereleasemethod.no setter - freeSpace → int
-
Available on File, provided by the File$$Methods extension
from:public long getFreeSpace()no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isAbsolute → bool
-
Available on File, provided by the File$$Methods extension
from:public boolean isAbsolute()no setter - isDirectory → bool
-
Available on File, provided by the File$$Methods extension
from:public boolean isDirectory()no setter - isFile → bool
-
Available on File, provided by the File$$Methods extension
from:public boolean isFile()no setter - isHidden → bool
-
Available on File, provided by the File$$Methods extension
from:public boolean isHidden()no setter - isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns
JClasscorresponding to concrete class of this object.no setterinherited - name → JString?
-
Available on File, provided by the File$$Methods extension
from:public java.lang.String getName()The returned object must be released after use, by calling thereleasemethod.no setter - parent → JString?
-
Available on File, provided by the File$$Methods extension
from:public java.lang.String getParent()The returned object must be released after use, by calling thereleasemethod.no setter - parentFile → File?
-
Available on File, provided by the File$$Methods extension
from:public java.io.File getParentFile()The returned object must be released after use, by calling thereleasemethod.no setter - path → JString?
-
Available on File, provided by the File$$Methods extension
from:public java.lang.String getPath()The returned object must be released after use, by calling thereleasemethod.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalSpace → int
-
Available on File, provided by the File$$Methods extension
from:public long getTotalSpace()no setter - usableSpace → int
-
Available on File, provided by the File$$Methods extension
from:public long getUsableSpace()no setter
Methods
-
as<
T extends JObject> (JType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
canExecute(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean canExecute() -
canRead(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean canRead() -
canWrite(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean canWrite() -
compareTo(
File? file) → int -
Available on File, provided by the File$$Methods extension
from:public int compareTo(java.io.File file) -
createNewFile(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean createNewFile() -
delete(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean delete() -
deleteOnExit(
) → void -
Available on File, provided by the File$$Methods extension
from:public void deleteOnExit() -
equals(
JObject? object) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean equals(java.lang.Object object) -
exists(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean exists() -
hashCode$1(
) → int -
Available on File, provided by the File$$Methods extension
from:public int hashCode() -
isA<
T extends JObject> (JType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
lastModified(
) → int -
Available on File, provided by the File$$Methods extension
from:public long lastModified() -
length(
) → int -
Available on File, provided by the File$$Methods extension
from:public long length() -
list(
) → JArray< JString?> ? -
Available on File, provided by the File$$Methods extension
from:public java.lang.String[] list()The returned object must be released after use, by calling thereleasemethod. -
list$1(
JObject? filenameFilter) → JArray< JString?> ? -
Available on File, provided by the File$$Methods extension
from:public java.lang.String[] list(java.io.FilenameFilter filenameFilter)The returned object must be released after use, by calling thereleasemethod. -
listFiles(
) → JArray< File?> ? -
Available on File, provided by the File$$Methods extension
from:public java.io.File[] listFiles()The returned object must be released after use, by calling thereleasemethod. -
listFiles$1(
JObject? fileFilter) → JArray< File?> ? -
Available on File, provided by the File$$Methods extension
from:public java.io.File[] listFiles(java.io.FileFilter fileFilter)The returned object must be released after use, by calling thereleasemethod. -
listFiles$2(
JObject? filenameFilter) → JArray< File?> ? -
Available on File, provided by the File$$Methods extension
from:public java.io.File[] listFiles(java.io.FilenameFilter filenameFilter)The returned object must be released after use, by calling thereleasemethod. -
mkdir(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean mkdir() -
mkdirs(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean mkdirs() -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
renameTo(
File? file) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean renameTo(java.io.File file) -
setExecutable(
bool z) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setExecutable(boolean z) -
setExecutable$1(
bool z, bool z1) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setExecutable(boolean z, boolean z1) -
setLastModified(
int j) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setLastModified(long j) -
setReadable(
bool z) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setReadable(boolean z) -
setReadable$1(
bool z, bool z1) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setReadable(boolean z, boolean z1) -
setReadOnly(
) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setReadOnly() -
setWritable(
bool z) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setWritable(boolean z) -
setWritable$1(
bool z, bool z1) → bool -
Available on File, provided by the File$$Methods extension
from:public boolean setWritable(boolean z, boolean z1) -
toPath(
) → JObject? -
Available on File, provided by the File$$Methods extension
from:public java.nio.file.Path toPath()The returned object must be released after use, by calling thereleasemethod. -
toString(
) → String -
A string representation of this object.
inherited
-
toString$1(
) → JString? -
Available on File, provided by the File$$Methods extension
from:public java.lang.String toString()The returned object must be released after use, by calling thereleasemethod. -
toURI(
) → JObject? -
Available on File, provided by the File$$Methods extension
from:public java.net.URI toURI()The returned object must be released after use, by calling thereleasemethod. -
toURL(
) → JObject? -
Available on File, provided by the File$$Methods extension
from:public java.net.URL toURL()The returned object must be released after use, by calling thereleasemethod.
Operators
-
operator <(
File? file) → bool -
Available on File, provided by the File$$Methods extension
-
operator <=(
File? file) → bool -
Available on File, provided by the File$$Methods extension
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
File? file) → bool -
Available on File, provided by the File$$Methods extension
-
operator >=(
File? file) → bool -
Available on File, provided by the File$$Methods extension
Static Properties
- pathSeparator → JString?
-
from:
static public final java.lang.String pathSeparatorThe returned object must be released after use, by calling thereleasemethod.no setter - pathSeparatorChar → int
-
from:
static public final char pathSeparatorCharno setter - separator → JString?
-
from:
static public final java.lang.String separatorThe returned object must be released after use, by calling thereleasemethod.no setter - separatorChar → int
-
from:
static public final char separatorCharno setter
Static Methods
-
createTempFile(
JString? string, JString? string1) → File? -
from:
static public java.io.File createTempFile(java.lang.String string, java.lang.String string1)The returned object must be released after use, by calling thereleasemethod. -
createTempFile$1(
JString? string, JString? string1, File? file) → File? -
from:
static public java.io.File createTempFile(java.lang.String string, java.lang.String string1, java.io.File file)The returned object must be released after use, by calling thereleasemethod. -
listRoots(
) → JArray< File?> ? -
from:
static public java.io.File[] listRoots()The returned object must be released after use, by calling thereleasemethod.