FoundationFFI class
Bindings for NSFileManager & URLResolve.
Constructors
- FoundationFFI(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
FoundationFFI.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
NSSearchPathForDirectoriesInDomains(
NSSearchPathDirectory directory, int domainMask, bool expandTilde) → NSArray -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited